from typing import Any, Iterable, Tuple, List, Union, Iterator
from itasca import types


def count(*args, **kwargs) -> int:
    """
    (<process: str>, <type: TypeObject>, <all=False>) -> int.
    Get the number of contacts.
    All the arguments to this function are optional.
    The first argument is the contact class, this defaults to "mechanical".
    If the (optional) keyword argument type is given the count is limited to that type.
    The type keyword argument should be a Python type object (itasca.BallBallContact, itasca.BallFacetContact, itasca.BallPebbleContact, itasca.PebblePebbleContact or itasca.PebbleFacetContact).
    If the (optional) keyword argument all is given, virtual contacts are included in the count.
    """
    pass


def energy(*args, **kwargs) -> float:
    """
    (energy_name: str, process="mechanical", type=TypeObject) -> float.
    Get energy values accumulated over contacts.
    The first argument should be the name of an energy quantity.
    Two optional keyword arguments are accepted, process which should be a string (defaults to "mechanical") and type which should be a Python contact type object.
    """
    pass


def find(*args, **kwargs) -> 'Contact':
    """
    (type: TypeObject, id: int or (object1, object2)) -> Contact object.
    Get the contact of the given type, the second argument is either an integer ID or a length two tuple containing two objects (for example a wall object and a ball object).
    """
    pass


def list(process_name="Mechanical", type=None, all=False) -> Iterator[types.Contacts]:
    """
    (process_name="Mechanical", type=None, all=False) -> Contact iterator object.
    Get a contact iterator object.
    The optional argument is the name of a process, the default is "mechanical".
    If the (optional) keyword argument type is given the returned contacts are limited to that type.
    The type keyword argument should be a Python type object (itasca.BallBallContact, itasca.BallFacetContact, itasca.BallPebbleContact, itasca.PebblePebbleContact or itasca.PebbleFacetContact).
    If the (optional) keyword argument all is given, virtual contacts are also returned.
    """
    pass


class Contact:
    __hash__: Any = ...

    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass

    def __eq__(self, other) -> Any:
        """
        Return self==value.
        """
        pass

    def __ge__(self, other) -> Any:
        """
        Return self>=value.
        """
        pass

    def __gt__(self, other) -> Any:
        """
        Return self>value.
        """
        pass

    def __le__(self, other) -> Any:
        """
        Return self<=value.
        """
        pass

    def __lt__(self, other) -> Any:
        """
        Return self<value.
        """
        pass

    def __ne__(self, other) -> Any:
        """
        Return self!=value.
        """
        pass


class ContactIter:
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass

    def __iter__(self) -> Any:
        """
        Implement iter(self).
        """
        pass

    def __next__(self) -> Any:
        """
        Implement next(self).
        """
        pass



from typing import Any

def _plist(*args, **kwargs) -> Any:
    """
    () -> tuple of PyObject pointers for the currenly in-scope and valid objects.
    This function is used for internal testing and is not needed for general PFC use.
    """
    pass

def count(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the number of rblock templates.
    """
    pass

def find(*args, **kwargs) -> Any:
    """
    (template_name: str) -> Template object.
    Find a rblock template by name.
    """
    pass

def findpebble(*args, **kwargs) -> Any:
    """
    (pebble_id: int) -> RBlock Template Pebble object.
    Find the rblock template pebble with the given ID, in the rblock template.
    """
    pass

def list(*args, **kwargs) -> Any:
    """
    () -> RBlock template iterator object.
    Get a rblock template iterator object.
    """
    pass

def maxid(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the maximum rblock templates ID.
    """
    pass

class Template:
    __hash__: Any = ...
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def delete(self, *args, **kwargs) -> Any:
        """
        () -> None.
        Delete this rblock template.
        All rblocks that referred to this rblock template no longer refer to any rblock template.
        """
        pass
    
    def id(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the rblock template id.
        """
        pass
    
    def moi(self, *args, **kwargs) -> Any:
        """
        () -> tensor.
        Get the rblock template moment of intertia.
        In 2D the polar moment of intertial is used so the return value is a float.
        """
        pass
    
    def moi_prin(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the rblock template principal moment of inertia (vector).
        """
        pass
    
    def moi_prin_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the rblock template principal moment of inertia.
        """
        pass
    
    def moi_prin_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the rblock template principal moment of inertia.
        """
        pass
    
    def name(self, *args, **kwargs) -> Any:
        """
        () -> str.
        Get the rblock template name.
        """
        pass
    
    def set_moi(self, *args, **kwargs) -> Any:
        """
        () -> tensor.
        Get the rblock template moment of intertia.
        In 2D the polar moment of intertial is used so the return value is a float.
        When modified no other rblock attributes are changed (e.g., pebble sizes, rblock volume, etc.).
        The specification of the moment of inertia in this way results in the principal moments of inertia being in a fixed state so that they will not be automatically updated when scaling a rblock unless the user changes the fix state (see the RBlock moi_fix() method).
        """
        pass
    
    def set_moi_prin(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the rblock template principal moment of inertia (vector).
        """
        pass
    
    def set_moi_prin_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the rblock template principal moment of inertia.
        """
        pass
    
    def set_moi_prin_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the rblock template principal moment of inertia.
        """
        pass
    
    def set_vol(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the rblock template volume.
        In 2D this is the volume per unit thickness.
        """
        pass
    
    def valid(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Returns True of this object is a live rblock template.
        """
        pass
    
    def vol(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the rblock template volume.
        In 2D this is the volume per unit thickness.
        """
        pass
    
    def __eq__(self, other) -> Any:
        """
        Return self==value.
        """
        pass
    
    def __ge__(self, other) -> Any:
        """
        Return self>=value.
        """
        pass
    
    def __gt__(self, other) -> Any:
        """
        Return self>value.
        """
        pass
    
    def __le__(self, other) -> Any:
        """
        Return self<=value.
        """
        pass
    
    def __lt__(self, other) -> Any:
        """
        Return self<value.
        """
        pass
    
    def __ne__(self, other) -> Any:
        """
        Return self!=value.
        """
        pass
    

class TemplateIter:
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def __iter__(self) -> Any:
        """
        Implement iter(self).
        """
        pass
    
    def __next__(self) -> Any:
        """
        Implement next(self).
        """
        pass
    



from typing import Any, Tuple

def _plist(*args, **kwargs) -> Any:
    """
    () -> tuple of PyObject pointers for the currenly in-scope and valid thermal ball objects.
    This function is used for internal testing and is not needed for general PFC use.
    """
    pass

def count(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the number of thermal balls.
    """
    pass

def find(*args, **kwargs) -> Any:
    """
    (id: int) -> Thermal ball object.
    Get the ball thermal object with the given ID number.
    """
    pass

def inbox(*args, **kwargs) -> Any:
    """
    (lower_bound: vec, upper_bound: vec, intersect=True) -> Tuple of thermal ball objects.
    Get a tuple of thermal balls with extents intersecting a box.
    The extent is the axis-aligned bounding box of the thermal ball.
    The if the optional keyword argument intersect is False then only balls with positions falling in the box are returned.
    """
    pass

def list(*args, **kwargs) -> Any:
    """
    () -> Thermal ball iterator object.
    Get a ball thermal iterator object.
    """
    pass

def maxid(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the maximum thermal ball ID.
    """
    pass

def near(*args, **kwargs) -> Any:
    """
    (point: vec, radius=0.0) -> Thermal ball object.
    Find the closest thermal ball to a point.
    If the optional keyword argument radius is non-zero, only search within this radius.
    """
    pass

class ThermalBall:
    __hash__: Any = ...
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def ball(self, *args, **kwargs) -> Any:
        """
        () -> Ball object.
        Get the ball corresponding to this thermal ball.
        """
        pass
    
    def contact_count(self, *args, **kwargs) -> Any:
        """
        (all=False, type=None) -> int.
        Get the number of contacts associated with this thermal ball.
        If the optional keyword argument type is given, the count is limited to the contact types specified.
        The optional type keyword argument should be a Python type object (one of: itasca.BallBallThermalContact, itasca.BallPebbleThermalContact, itasca.PebblePebbleThermalContact, itasca.BallFacetThermalContact or itasca.PebbleFacetThermalContact).
        If the optional keyword argument all is True the count includes virtual contacts.
        """
        pass
    
    def contacts(self, *args, **kwargs) -> Any:
        """
        ([piece], all=False, type=None) -> tuple of Contact objects.
        Get a tuple of contacts associated with this thermal ball.
        An optional argument can be included which is a piece object (a thermal ball, a thermal pebble or a thermal facet).
        If the optional keyword argument type is given, the returned list is limited to the contact types specified.
        The type keyword argument should be a Python type object (one of: itasca.BallBallThermalContact, itasca.BallPebbleThermalContact, itasca.PebblePebbleThermalContact, itasca.BallFacetThermalContact or itasca.PebbleFacetThermalContact).
        If the (optional) keyword argument all is True the returned list includes virtual contacts.
        """
        pass
    
    def del_temp(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the thermal ball temperature increment.
        """
        pass
    
    def expansion(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the thermal ball expansion coefficient.
        """
        pass
    
    def extra(self, *args, **kwargs) -> Any:
        """
        (slot: int) -> any.
        Get the thermal ball extra data in the given slot.
        """
        pass
    
    def fix(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Get the thermal ball fixity.
        """
        pass
    
    def group(self, *args, **kwargs) -> Any:
        """
        ([slot: int]) -> str.
        Get the thermal ball group name in a given slot.
        """
        pass
    
    def group_remove(self, *args, **kwargs) -> Any:
        """
        (group_name: str ) -> int.
        Remove from the given group from the thermal ball.
        One argument of type string, giving the group name, is required.
        The return value is an integer which is the first slot in which the group name was found or -1 if not found.
        """
        pass
    
    def groups(self, *args, **kwargs) -> Any:
        """
        () -> tuple of strings.
        Get a tuple of group names assigned to this thermal ball.
        """
        pass
    
    def has_prop(self, *args, **kwargs) -> Any:
        """
        (property_name: str) -> bool.
        Returns True if the thermal ball has the given surface property.
        """
        pass
    
    def id(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the thermal ball id.
        """
        pass
    
    def in_group(self, *args, **kwargs) -> Any:
        """
        (group_name: str) -> bool.
        Test if the thermal ball is part of a given group.
        All group slots are searched.
        """
        pass
    
    def pos(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the thermal ball location (vector).
        """
        pass
    
    def pos_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the thermal ball location.
        """
        pass
    
    def pos_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the thermal ball location.
        """
        pass
    
    def power_app(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the thermal ball applied power.
        """
        pass
    
    def power_unbal(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the thermal ball unbalanced power.
        """
        pass
    
    def prop(self, *args, **kwargs) -> Any:
        """
        (property_name: str) -> any.
        Get a surface property value of this thermal ball.
        """
        pass
    
    def props(self, *args, **kwargs) -> Any:
        """
        () -> dict {str: any}.
        Get a dictionary of all the surface properties of this thermal ball.
        """
        pass
    
    def set_del_temp(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the thermal ball temperature increment.
        """
        pass
    
    def set_expansion(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the thermal ball expansion coefficient.
        """
        pass
    
    def set_extra(self, *args, **kwargs) -> Any:
        """
        (slot: int, value: any) -> None.
        Set the thermal ball extra data in the given slot.
        """
        pass
    
    def set_fix(self, *args, **kwargs) -> Any:
        """
        (value: bool) -> None.
        Set the thermal ball fixity.
        """
        pass
    
    def set_group(self, *args, **kwargs) -> Any:
        """
        ([group_name: str[, slot: int]]) -> None.
        Set the thermal ball group name in a given slot.
        """
        pass
    
    def set_pos(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the thermal ball location (vector).
        """
        pass
    
    def set_pos_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the thermal ball location.
        """
        pass
    
    def set_pos_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the thermal ball location.
        """
        pass
    
    def set_power_app(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the thermal ball applied power.
        """
        pass
    
    def set_prop(self, *args, **kwargs) -> Any:
        """
        (property_name: str, value: any) -> None.
        Set a surface property of this thermal ball.
        """
        pass
    
    def set_specific_heat(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the thermal ball specific heat.
        """
        pass
    
    def set_temp(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the thermal ball temperature.
        """
        pass
    
    def specific_heat(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the thermal ball specific heat.
        """
        pass
    
    def temp(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the thermal ball temperature.
        """
        pass
    
    def valid(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Returns True if this thermal ball is live.
        """
        pass
    
    def __eq__(self, other) -> Any:
        """
        Return self==value.
        """
        pass
    
    def __ge__(self, other) -> Any:
        """
        Return self>=value.
        """
        pass
    
    def __gt__(self, other) -> Any:
        """
        Return self>value.
        """
        pass
    
    def __le__(self, other) -> Any:
        """
        Return self<=value.
        """
        pass
    
    def __lt__(self, other) -> Any:
        """
        Return self<value.
        """
        pass
    
    def __ne__(self, other) -> Any:
        """
        Return self!=value.
        """
        pass
    

class ThermalBallIter:
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def __iter__(self) -> Any:
        """
        Implement iter(self).
        """
        pass
    
    def __next__(self) -> Any:
        """
        Implement next(self).
        """
        pass
    



from typing import Any

def _plist(*args, **kwargs) -> Any:
    """
    () -> tuple of PyObject pointers for the currenly in-scope and valid objects.
    This function is used for internal testing and is not needed for general PFC use.
    """
    pass

def count(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the number of facets.
    """
    pass

def find(*args, **kwargs) -> Any:
    """
    (id: int) -> Facet object.
    Get the facet object with the given ID number.
    """
    pass

def inbox(*args, **kwargs) -> Any:
    """
    (lower_bound: vec, upper_bound: vec, boundary=False) -> tuple of Facet objects.
    Get facets with extents intersecting a box.
    If the optional keyword argument boundary is True only return the facets inside the extent.
    """
    pass

def list(*args, **kwargs) -> Any:
    """
    () -> Facet Iterator object.
    Get a wall_facet iterator object.
    """
    pass

def maxid(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the maximum facet ID.
    """
    pass

def near(*args, **kwargs) -> Any:
    """
    (point: vec) -> Facet object.
    Find the closest facet to a point.
    """
    pass

class Facet:
    __hash__: Any = ...
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def active(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the facet activity code.
        The following codes apply: 0 - both sides are active; 1 - the top side (e.g., in the direction of the facet normal) is active; -1 - the bottom side of the facet is active; or 2 - neither side of the facet is active.
        """
        pass
    
    def contact_count(self, *args, **kwargs) -> Any:
        """
        (all=False, type=None) -> int.
        Get the number of contacts associated with this Facet.
        If the optional keyword argument type is given, the count is limited to the contact types specified.
        The type keyword argument should be a Python type object (one of: itasca.BallBallContact, itasca.BallPebbleContact, itasca.PebblePebbleContact, itasca.BallFacetContact or itasca.PebbleFacetContact).
        If the (optional) keyword argument all is True the count includes virtual contacts.
        """
        pass
    
    def contacts(self, *args, **kwargs) -> Any:
        """
        ([piece: object], all=False, type=None) -> tuple of Contact objects.
        Get a tuple of contacts associated with this Facet.
        An optional argument can be included which is a piece object (a Ball, a Pebble or a Facet).
        If the optional keyword argument type is given, the returned list is limited to the contact types specified.
        The type keyword argument should be a Python type object (one of: itasca.BallBallContact, itasca.BallPebbleContact, itasca.PebblePebbleContact, itasca.BallFacetContact or itasca.PebbleFacetContact).
        If the (optional) keyword argument all is True the returned list includes virtual contacts.
        """
        pass
    
    def conveyor(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the facet conveyor velocity (vector).
        """
        pass
    
    def conveyor_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the facet conveyor velocity.
        """
        pass
    
    def conveyor_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the facet conveyor velocity.
        """
        pass
    
    def delete(self, *args, **kwargs) -> Any:
        """
        () -> None.
        Delete a facet.
        The wall position is automatically updated.
        """
        pass
    
    def edge_neighbors(self, *args, **kwargs) -> Any:
        """
        () -> tuple of Facet objects.
        Get the neighboring facets.
        Neighboring facets are those sharing a {vertex in 2D; edge in 3D}.
        The tuple is length 3 in 3D and length 2 in 2D.
        Each position in the tuple contains either a Facet object or None if no facet is adjacent to that edge (point in 2d).
        """
        pass
    
    def extra(self, *args, **kwargs) -> Any:
        """
        (slot: int) -> any.
        Get the facet extra data in the given slot.
        """
        pass
    
    def group(self, *args, **kwargs) -> Any:
        """
        ([slot: str]) -> str.
        Get the facet group name in a given slot.
        """
        pass
    
    def group_remove(self, *args, **kwargs) -> Any:
        """
        (group_name: str) -> bool.
        Remove from the given group from all group slots of the facet.
        One argument of type string, giving the group name, is required.
        The return value is a bool which is True if the group was removed from any slot, otherwise False.
        """
        pass
    
    def groups(self, *args, **kwargs) -> Any:
        """
        () -> {slot: group_name}.
        Get a dictionary describing which groups this facet is part of.
        The keys of the dictionary are the slot names and the values are the group names.
        """
        pass
    
    def has_prop(self, *args, **kwargs) -> Any:
        """
        (property_name: str) -> bool.
        Returns True if the facet has the given surface property.
        """
        pass
    
    def id(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the facet id.
        """
        pass
    
    def in_group(self, *args, **kwargs) -> Any:
        """
        (group_name: str[, slot: str]) -> bool.
        Test if the facet is part of a given group.
        If the optional argument slot is given, only that slot is searched.
        Otherwise, all group slots are searched.
        """
        pass
    
    def normal(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the facet normal direction (vector).
        """
        pass
    
    def normal_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the facet normal direction.
        """
        pass
    
    def normal_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the facet normal direction.
        """
        pass
    
    def point_near(self, *args, **kwargs) -> Any:
        """
        (point: vec) -> vec.
        Get the closest point on the facet to another point.
        """
        pass
    
    def pos(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the facet location (vector).
        """
        pass
    
    def pos_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the facet location.
        """
        pass
    
    def pos_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the facet location.
        """
        pass
    
    def prop(self, *args, **kwargs) -> Any:
        """
        (property_name: str) -> any.
        Get a surface property value of this facet.
        """
        pass
    
    def props(self, *args, **kwargs) -> Any:
        """
        () -> dict {str: any}.
        Get a dictionary of all the surface properties of this facet.
        """
        pass
    
    def set_active(self, *args, **kwargs) -> Any:
        """
        (activity_code: int) -> None.
        The following codes apply: 0 - both sides are active; 1 - the top side (e.g., in the direction of the facet normal) is active; -1 - the bottom side of the facet is active; or 2 - neither side of the facet is active.
        """
        pass
    
    def set_conveyor(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the facet conveyor velocity (vector).
        """
        pass
    
    def set_conveyor_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the facet conveyor velocity.
        """
        pass
    
    def set_conveyor_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the facet conveyor velocity.
        """
        pass
    
    def set_extra(self, *args, **kwargs) -> Any:
        """
        (slot: int, value: any) -> None.
        Set the facet extra data in the given slot.
        """
        pass
    
    def set_group(self, *args, **kwargs) -> Any:
        """
        (group_name: str[, slot: str]) -> None.
        Set the facet group name in a given slot.
        """
        pass
    
    def set_prop(self, *args, **kwargs) -> Any:
        """
        (property_name: str, value: any) -> None.
        Set a surface property of this facet.
        """
        pass
    
    def valid(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Returns True if this facet is live.
        """
        pass
    
    def vertices(self, *args, **kwargs) -> Any:
        """
        () -> tuple of WallVertex objects.
        Get the facet vertices.
        """
        pass
    
    def wall(self, *args, **kwargs) -> Any:
        """
        () -> Wall object.
        Get the facet's wall.
        """
        pass
    
    def __eq__(self, other) -> Any:
        """
        Return self==value.
        """
        pass
    
    def __ge__(self, other) -> Any:
        """
        Return self>=value.
        """
        pass
    
    def __gt__(self, other) -> Any:
        """
        Return self>value.
        """
        pass
    
    def __le__(self, other) -> Any:
        """
        Return self<=value.
        """
        pass
    
    def __lt__(self, other) -> Any:
        """
        Return self<value.
        """
        pass
    
    def __ne__(self, other) -> Any:
        """
        Return self!=value.
        """
        pass
    

class FacetIter:
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def __iter__(self) -> Any:
        """
        Implement iter(self).
        """
        pass
    
    def __next__(self) -> Any:
        """
        Implement next(self).
        """
        pass
    



from typing import Any

def cutoff(*args, **kwargs) -> Any:
    """
    () -> array float{wall}.
    Get a numpy array of the wall cutoff angle.
    """
    pass

def disp(*args, **kwargs) -> Any:
    """
    () -> array float{wall,2}.
    Get a numpy array of the wall displacement.
    """
    pass

def extra(*args, **kwargs) -> Any:
    """
    (slot: int) -> array float{wall} or float{wall}.
    Get the wall extra data in the given slot as an array.
    Extra variables accessed by array must be of type float or vec.
    """
    pass

def fill_cutoff(*args, **kwargs) -> Any:
    """
    (data: array float{wall}) -> None.
    Fill an existing array with the wall cutoff angle.
    The array must be the correct shape.
    """
    pass

def fill_disp(*args, **kwargs) -> Any:
    """
    (data: array float{wall,2}) -> None.
    Fill an existing array with the wall displacement.
    The array must be the correct shape.
    """
    pass

def fill_force_contact(*args, **kwargs) -> Any:
    """
    (data: array float{wall,2}) -> None.
    Fill an existing array with the wall contact force.
    The array must be the correct shape.
    """
    pass

def fill_moment_contact(*args, **kwargs) -> Any:
    """
    (data: array float{wall}) -> None.
    Fill an existing array with the wall contact moment.
    The array must be the correct shape.
    """
    pass

def fill_pos(*args, **kwargs) -> Any:
    """
    (data: array float{wall,2}) -> None.
    Fill an existing array with the wall location.
    The array must be the correct shape.
    """
    pass

def fill_rotation(*args, **kwargs) -> Any:
    """
    (data: array float{wall}) -> None.
    Fill an existing array with the wall orientation.
    The array must be the correct shape.
    """
    pass

def fill_rotation_center(*args, **kwargs) -> Any:
    """
    (data: array float{wall,dim}) -> None.
    Fill an existing array with the wall center of rotation.
    The array must be the correct shape.
    """
    pass

def fill_spin(*args, **kwargs) -> Any:
    """
    (data: array float{wall}) -> None.
    Fill an existing array with the wall angular velocity.
    The array must be the correct shape.
    """
    pass

def fill_vel(*args, **kwargs) -> Any:
    """
    (data: array float{wall,2}) -> None.
    Fill an existing array with the wall velocity.
    The array must be the correct shape.
    """
    pass

def force_contact(*args, **kwargs) -> Any:
    """
    () -> array float{wall,2}.
    Get a numpy array of the wall contact force.
    """
    pass

def ids(*args, **kwargs) -> Any:
    """
    () -> array int{wall}.
    Get the wall ids as an array.
    """
    pass

def in_group(*args, **kwargs) -> Any:
    """
    (group_name: str, slot=1) -> array bool{wall}.
    Return wall group membership as a Boolean array.
    """
    pass

def moment_contact(*args, **kwargs) -> Any:
    """
    () -> array float{wall}.
    Get a numpy array of the wall contact moment.
    """
    pass

def pos(*args, **kwargs) -> Any:
    """
    () -> array float{wall,2}.
    Get a numpy array of the wall location.
    """
    pass

def rotation(*args, **kwargs) -> Any:
    """
    () -> array float{wall}.
    Get a numpy array of the wall orientation.
    """
    pass

def rotation_center(*args, **kwargs) -> Any:
    """
    () -> array float{wall,dim}.
    Get a numpy array of the wall center of rotation.
    """
    pass

def set_cutoff(*args, **kwargs) -> Any:
    """
    (data: array float{wall}) -> None.
    Set the wall cutoff angle from an array.
    """
    pass

def set_disp(*args, **kwargs) -> Any:
    """
    (data: array float{wall,2}) -> None.
    Set the wall displacement from an array.
    """
    pass

def set_extra(*args, **kwargs) -> Any:
    """
    (slot: int, data: array float{wall} or float{wall}) -> None.
    Set the wall extra data in the given slot with an array.
    Extra variables set by array must be of type float or vec.
    """
    pass

def set_force_contact(*args, **kwargs) -> Any:
    """
    (data: array float{wall,2}) -> None.
    Set the wall contact force from an array.
    """
    pass

def set_group(*args, **kwargs) -> Any:
    """
    (membership: array bool{wall}, group_name: str, slot=1) -> None.
    Set wall group from an array.
    Where membership True set the corresponding wall to be a member of group group_name in the given slot.
    """
    pass

def set_moment_contact(*args, **kwargs) -> Any:
    """
    (data: array float{wall}) -> None.
    Set the wall contact moment from an array.
    """
    pass

def set_pos(*args, **kwargs) -> Any:
    """
    (data: array float{wall,2}) -> None.
    Set the wall location from an array.
    """
    pass

def set_rotation(*args, **kwargs) -> Any:
    """
    (data: array float{wall}) -> None.
    Set the wall orientation from an array.
    """
    pass

def set_rotation_center(*args, **kwargs) -> Any:
    """
    ((data: array float{wall,dim}) -> None.
    Set the wall center of rotation from an array.
    """
    pass

def set_spin(*args, **kwargs) -> Any:
    """
    (data: array float{wall}) -> None.
    Set the wall angular velocity from an array.
    """
    pass

def set_vel(*args, **kwargs) -> Any:
    """
    (data: array float{wall,2}) -> None.
    Set the wall velocity from an array.
    """
    pass

def spin(*args, **kwargs) -> Any:
    """
    () -> array float{wall}.
    Get a numpy array of the wall angular velocity.
    """
    pass

def vel(*args, **kwargs) -> Any:
    """
    () -> array float{wall,2}.
    Get a numpy array of the wall velocity.
    """
    pass




from typing import Any

def _plist(*args, **kwargs) -> Any:
    """
    () -> tuple of PyObject pointers for the currenly in-scope and valid objects.
    This function is used for internal testing and is not needed for general PFC use.
    """
    pass

def count(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the number of clump templates.
    """
    pass

def find(*args, **kwargs) -> Any:
    """
    (template_name: str) -> Template object.
    Find a clump template by name.
    """
    pass

def findpebble(*args, **kwargs) -> Any:
    """
    (pebble_id: int) -> Clump Template Pebble object.
    Find the clump template pebble with the given ID, in the clump template.
    """
    pass

def list(*args, **kwargs) -> Any:
    """
    () -> Clump template iterator object.
    Get a clump template iterator object.
    """
    pass

def make(*args, **kwargs) -> Any:
    """
    (clump template: Clump template object, template_name: str) -> Template object.
    Make a clump template from a clump.
    No clumps refer to the created clump template.
    """
    pass

def maxid(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the maximum clump templates ID.
    """
    pass

class Template:
    __hash__: Any = ...
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def add_pebble(self, *args, **kwargs) -> Any:
        """
        (pebble_radius: float, pebble_position: vec [,pebble_id: int]) -> TemplatePebble object.
        Add a pebble to a clump template.
        This operation has no impact on the clump template inertial attributes.
        If the optional argument ID is not specified the id if the newly created pebble is set to the next available number.
        """
        pass
    
    def clone(self, *args, **kwargs) -> Any:
        """
        (new_template_name: str) -> Template object.
        Clone this clump template.
        The new clump template has name new_template_name and no clumps refer to the created clump template.
        """
        pass
    
    def delete(self, *args, **kwargs) -> Any:
        """
        () -> None.
        Delete this clump template.
        All clumps that referred to this clump template no longer refer to any clump template.
        """
        pass
    
    def delete_pebble(self, *args, **kwargs) -> Any:
        """
        (pebble: TemplatePebbel object) -> None.
        Delete a TemplatePebble from this clump.
        This operation has no impact on the clump template inertial attributes.
        The clump no longer refers to a clump template.
        This operation will raise an exception if any clumps refer to the clump template.
        """
        pass
    
    def id(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the clump template id.
        """
        pass
    
    def moi(self, *args, **kwargs) -> Any:
        """
        () -> tensor.
        Get the clump template moment of intertia.
        In 2D the polar moment of intertial is used so the return value is a float.
        """
        pass
    
    def moi_prin(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the clump template principal moment of inertia (vector).
        """
        pass
    
    def moi_prin_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the clump template principal moment of inertia.
        """
        pass
    
    def moi_prin_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the clump template principal moment of inertia.
        """
        pass
    
    def name(self, *args, **kwargs) -> Any:
        """
        () -> str.
        Get the clump template name.
        """
        pass
    
    def orig_pos(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the clump template original position (vector).
        """
        pass
    
    def orig_pos_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the clump template original position.
        """
        pass
    
    def orig_pos_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the clump template original position.
        """
        pass
    
    def pebbles(self, *args, **kwargs) -> Any:
        """
        () -> tuple of TemplatePebble objects.
        Get the pebbles of this clump template.
        """
        pass
    
    def set_moi(self, *args, **kwargs) -> Any:
        """
        () -> tensor.
        Get the clump template moment of intertia.
        In 2D the polar moment of intertial is used so the return value is a float.
        When modified no other clump attributes are changed (e.g., pebble sizes, clump volume, etc.).
        The specification of the moment of inertia in this way results in the principal moments of inertia being in a fixed state so that they will not be automatically updated when scaling a clump unless the user changes the fix state (see the Clump moi_fix() method).
        """
        pass
    
    def set_moi_prin(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the clump template principal moment of inertia (vector).
        """
        pass
    
    def set_moi_prin_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the clump template principal moment of inertia.
        """
        pass
    
    def set_moi_prin_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the clump template principal moment of inertia.
        """
        pass
    
    def set_orig_pos(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the clump template original position (vector).
        """
        pass
    
    def set_orig_pos_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the clump template original position.
        """
        pass
    
    def set_orig_pos_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the clump template original position.
        """
        pass
    
    def set_vol(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the clump template volume.
        In 2D this is the volume per unit thickness.
        """
        pass
    
    def valid(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Returns True of this object is a live clump template.
        """
        pass
    
    def vol(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the clump template volume.
        In 2D this is the volume per unit thickness.
        """
        pass
    
    def __eq__(self, other) -> Any:
        """
        Return self==value.
        """
        pass
    
    def __ge__(self, other) -> Any:
        """
        Return self>=value.
        """
        pass
    
    def __gt__(self, other) -> Any:
        """
        Return self>value.
        """
        pass
    
    def __le__(self, other) -> Any:
        """
        Return self<=value.
        """
        pass
    
    def __lt__(self, other) -> Any:
        """
        Return self<value.
        """
        pass
    
    def __ne__(self, other) -> Any:
        """
        Return self!=value.
        """
        pass
    

class TemplateIter:
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def __iter__(self) -> Any:
        """
        Implement iter(self).
        """
        pass
    
    def __next__(self) -> Any:
        """
        Implement next(self).
        """
        pass
    



from typing import Any

def _plist(*args, **kwargs) -> Any:
    """
    () -> tuple of PyObject pointers for the currenly in-scope and valid Measure objects.
    This function is used for internal testing and is not needed for general PFC use.
    """
    pass

def count(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the number of measures.
    """
    pass

def find(*args, **kwargs) -> Any:
    """
    (id: int) -> Measure object.
    Get the measure object with the given ID number.
    """
    pass

def list(*args, **kwargs) -> Any:
    """
    () -> Measure iterator object.
    Get a measure iterator object.
    """
    pass

def maxid(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the maximum measure ID.
    """
    pass

class Measure:
    __hash__: Any = ...
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def coordination(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the measure coordination.
        """
        pass
    
    def delete(self, *args, **kwargs) -> Any:
        """
        () -> None.
        Delete this measurement object.
        """
        pass
    
    def id(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the measure id.
        """
        pass
    
    def porosity(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the measure porosity.
        """
        pass
    
    def pos(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the measure location (vector).
        """
        pass
    
    def pos_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the measure location.
        """
        pass
    
    def pos_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the measure location.
        """
        pass
    
    def radius(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the measure radius.
        """
        pass
    
    def set_pos(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the measure location (vector).
        """
        pass
    
    def set_pos_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the measure location.
        """
        pass
    
    def set_pos_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the measure location.
        """
        pass
    
    def set_radius(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the measure radius.
        """
        pass
    
    def size(self, *args, **kwargs) -> Any:
        """
        () -> array float{nbin,2}.
        Get a numpy array of the cumulative size distribution falling withinthis measure object where nbin is the number of bins for the size distribution calculation (see the MEASURE CREATE or MEASURE MODIFY commands.
        """
        pass
    
    def strainrate(self, *args, **kwargs) -> Any:
        """
        () -> tensor.
        Get the strain rate tensor calculated for this measurement object.
        """
        pass
    
    def strainrate_full(self, *args, **kwargs) -> Any:
        """
        () -> tensor.
        Get the full strain rate tensor calculated for this measurement object.
        """
        pass
    
    def stress(self, *args, **kwargs) -> Any:
        """
        () -> tensor.
        Get the stress tensor calculated for this measurement object.
        """
        pass
    
    def stress_full(self, *args, **kwargs) -> Any:
        """
        () -> tensor.
        Get the full stress tensor calculated for this measurement object.
        """
        pass
    
    def valid(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Returns True if this measure is live.
        """
        pass
    
    def __eq__(self, other) -> Any:
        """
        Return self==value.
        """
        pass
    
    def __ge__(self, other) -> Any:
        """
        Return self>=value.
        """
        pass
    
    def __gt__(self, other) -> Any:
        """
        Return self>value.
        """
        pass
    
    def __le__(self, other) -> Any:
        """
        Return self<=value.
        """
        pass
    
    def __lt__(self, other) -> Any:
        """
        Return self<value.
        """
        pass
    
    def __ne__(self, other) -> Any:
        """
        Return self!=value.
        """
        pass
    

class MeasureIter:
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def __iter__(self) -> Any:
        """
        Implement iter(self).
        """
        pass
    
    def __next__(self) -> Any:
        """
        Implement next(self).
        """
        pass
    



from typing import Any

def _plist(*args, **kwargs) -> Any:
    """
    () -> tuple of PyObject pointers for the currenly in-scope and valid intersect objects.
    This function is used for internal testing and is not needed for general PFC use.
    """
    pass

def count(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the number of intersections.
    """
    pass

def find(*args, **kwargs) -> Any:
    """
    (id: int) -> Intersection object.
    Get the intersection object with the given ID number.
    """
    pass

def list(*args, **kwargs) -> Any:
    """
    () -> Intersection iterator object.
    Get an intersection iterator object.
    """
    pass

def maxid(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the maximum intersection ID.
    """
    pass

class Inter:
    __hash__: Any = ...
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def end1(self, *args, **kwargs) -> Any:
        """
        () -> Fracture object.
        Get the end1 fracture object.
        """
        pass
    
    def end2(self, *args, **kwargs) -> Any:
        """
        () -> Fracture object.
        Get the end2 fracture object.
        """
        pass
    
    def extra(self, *args, **kwargs) -> Any:
        """
        (slot: int) -> any.
        Get the intersection extra data in the given slot.
        """
        pass
    
    def group(self, *args, **kwargs) -> Any:
        """
        ([slot: str]) -> str.
        Get the intersection group name in a given slot.
        """
        pass
    
    def group_remove(self, *args, **kwargs) -> Any:
        """
        (group_name: str) -> bool.
        Remove from the given group from all group slots of the intersection.
        One argument of type string, giving the group name, is required.
        The return value is a bool which is True if the group was removed from any slot, otherwise False.
        """
        pass
    
    def groups(self, *args, **kwargs) -> Any:
        """
        () -> {slot: group_name}.
        Get a dictionary describing which groups this intersection is part of.
        The keys of the dictionary are the slot names and the values are the group names.
        """
        pass
    
    def id(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the intersection id.
        """
        pass
    
    def in_group(self, *args, **kwargs) -> Any:
        """
        (group_name: str[, slot: str]) -> bool.
        Test if the intersection is part of a given group.
        If the optional argument slot is given, only that slot is searched.
        Otherwise, all group slots are searched.
        """
        pass
    
    def pos1(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the intersection first end position (vector).
        """
        pass
    
    def pos1_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the intersection first end position.
        """
        pass
    
    def pos1_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the intersection first end position.
        """
        pass
    
    def pos2(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the intersection second end position (vector).
        """
        pass
    
    def pos2_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the intersection second end position.
        """
        pass
    
    def pos2_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the intersection second end position.
        """
        pass
    
    def set(self, *args, **kwargs) -> Any:
        """
        () -> Intersection set object.
        Get the intersection set to which this intersection belongs.
        """
        pass
    
    def set_extra(self, *args, **kwargs) -> Any:
        """
        (slot: int, value: any) -> None.
        Set the intersection extra data in the given slot.
        """
        pass
    
    def set_group(self, *args, **kwargs) -> Any:
        """
        (group_name: str[, slot: str]) -> None.
        Set the intersection group name in a given slot.
        """
        pass
    
    def valid(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Returns True if this intersection is live.
        """
        pass
    
    def __eq__(self, other) -> Any:
        """
        Return self==value.
        """
        pass
    
    def __ge__(self, other) -> Any:
        """
        Return self>=value.
        """
        pass
    
    def __gt__(self, other) -> Any:
        """
        Return self>value.
        """
        pass
    
    def __le__(self, other) -> Any:
        """
        Return self<=value.
        """
        pass
    
    def __lt__(self, other) -> Any:
        """
        Return self<value.
        """
        pass
    
    def __ne__(self, other) -> Any:
        """
        Return self!=value.
        """
        pass
    

class InterIter:
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def __iter__(self) -> Any:
        """
        Implement iter(self).
        """
        pass
    
    def __next__(self) -> Any:
        """
        Implement next(self).
        """
        pass
    



from typing import Any

def fill_pos(*args, **kwargs) -> Any:
    """
    (data: array float{vertex,2}) -> None.
    Fill an existing array with the vertex location.
    The array must be the correct shape.
    """
    pass

def fill_vel(*args, **kwargs) -> Any:
    """
    (data: array float{vertex,2}) -> None.
    Fill an existing array with the vertex velocity.
    The array must be the correct shape.
    """
    pass

def ids(*args, **kwargs) -> Any:
    """
    () -> array int{vertex}.
    Get the vertex ids as an array.
    """
    pass

def pos(*args, **kwargs) -> Any:
    """
    () -> array float{vertex,2}.
    Get a numpy array of the vertex location.
    """
    pass

def set_pos(*args, **kwargs) -> Any:
    """
    (data: array float{vertex,2}) -> None.
    Set the vertex location from an array.
    """
    pass

def set_vel(*args, **kwargs) -> Any:
    """
    (data: array float{vertex,2}) -> None.
    Set the vertex velocity from an array.
    """
    pass

def vel(*args, **kwargs) -> Any:
    """
    () -> array float{vertex,2}.
    Get a numpy array of the vertex velocity.
    """
    pass




from typing import Any, Tuple

def _plist(*args, **kwargs) -> Any:
    """
    () -> tuple of PyObject pointers for the currenly in-scope and valid Clump objects.
    This function is used for internal testing and is not needed for general PFC use.
    """
    pass

def count(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the number of pebbles.
    """
    pass

def find(*args, **kwargs) -> Any:
    """
    (id: int) -> Pebble object.
    Get the Pebble object with the given ID number.
    """
    pass

def inbox(*args, **kwargs) -> Any:
    """
    (lower_bound: vec, upper_bound: vec, intersect=True) -> Tuple of Pebble objects.
    Get a tuple of pebbles with extents intersecting a box.
    The extent is the axis-aligned bounding box of the pebble.
    The if the optional keyword argument intersect is False only pebbles with positions falling in the box are returned.
    """
    pass

def list(*args, **kwargs) -> Any:
    """
    () -> Pebble iterator object.
    Get a pebble iterator object.
    """
    pass

def maxid(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the maximum pebble ID.
    """
    pass

def near(*args, **kwargs) -> Any:
    """
    (point: vec, radius=0.0) -> Pebble object.
    Find the closest pebble to a point.
    If the optional keyword argument radius is non-zero, only search within this radius.
    """
    pass

class Pebble:
    __hash__: Any = ...
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def clump(self, *args, **kwargs) -> Any:
        """
        () -> Clump object.
        Get the clump object to which this pebble belongs.
        """
        pass
    
    def contacts(self, *args, **kwargs) -> Any:
        """
        ([piece: object], all=False, type=None) -> tuple of Contact objects.
        Get a tuple of contacts associated with this ball.
        An optional argument can be included which is a piece object (a Ball, a Pebble or a Facet).
        If the optional keyword argument type is given, the returned list is limited to the contact types specified.
        The type keyword argument should be a Python type object (one of: itasca.BallBallContact, itasca.BallPebbleContact, itasca.PebblePebbleContact, itasca.BallFacetContact or itasca.PebbleFacetContact).
        If the (optional) keyword argument all is True the returned list includes virtual contacts.
        """
        pass
    
    def delete(self, *args, **kwargs) -> Any:
        """
        () -> None.
        Delete this pebble.
        """
        pass
    
    def extra(self, *args, **kwargs) -> Any:
        """
        (slot: int) -> any.
        Get the pebble extra data in the given slot.
        """
        pass
    
    def group(self, *args, **kwargs) -> Any:
        """
        ([slot: str]) -> str.
        Get the pebble group name in a given slot.
        """
        pass
    
    def group_remove(self, *args, **kwargs) -> Any:
        """
        (group_name: str) -> bool.
        Remove from the given group from all group slots of the pebble.
        One argument of type string, giving the group name, is required.
        The return value is a bool which is True if the group was removed from any slot, otherwise False.
        """
        pass
    
    def groups(self, *args, **kwargs) -> Any:
        """
        () -> {slot: group_name}.
        Get a dictionary describing which groups this pebble is part of.
        The keys of the dictionary are the slot names and the values are the group names.
        """
        pass
    
    def has_prop(self, *args, **kwargs) -> Any:
        """
        (property_name: str) -> bool.
        Returns True if the pebble has the given surface property.
        """
        pass
    
    def id(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the pebble id.
        """
        pass
    
    def in_group(self, *args, **kwargs) -> Any:
        """
        (group_name: str[, slot: str]) -> bool.
        Test if the pebble is part of a given group.
        If the optional argument slot is given, only that slot is searched.
        Otherwise, all group slots are searched.
        """
        pass
    
    def pos(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the pebble location (vector).
        """
        pass
    
    def pos_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the pebble location.
        """
        pass
    
    def pos_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the pebble location.
        """
        pass
    
    def prop(self, *args, **kwargs) -> Any:
        """
        (property_name: str) -> any.
        Get a surface property value of this pebble.
        """
        pass
    
    def props(self, *args, **kwargs) -> Any:
        """
        () -> dict {str: any}.
        Get a dictionary of all the surface properties of this pebble.
        """
        pass
    
    def radius(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the pebble radius.
        """
        pass
    
    def set_extra(self, *args, **kwargs) -> Any:
        """
        (slot: int, value: any) -> None.
        Set the pebble extra data in the given slot.
        """
        pass
    
    def set_group(self, *args, **kwargs) -> Any:
        """
        (group_name: str[, slot: str]) -> None.
        Set the pebble group name in a given slot.
        """
        pass
    
    def set_pos(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the pebble location.
        (vector).
        """
        pass
    
    def set_pos_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the pebble location.
        """
        pass
    
    def set_pos_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the pebble location.
        """
        pass
    
    def set_prop(self, *args, **kwargs) -> Any:
        """
        (property_name: str, value: any) -> None.
        Set a surface property of this pebble.
        """
        pass
    
    def set_radius(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the pebble radius.
        """
        pass
    
    def template(self, *args, **kwargs) -> Any:
        """
        () -> Template object.
        Get the clump template this pebble belongs to.
        """
        pass
    
    def valid(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Returns True if this pebble is live.
        """
        pass
    
    def vel(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the pebble velocity (vector).
        """
        pass
    
    def vel_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the pebble velocity.
        """
        pass
    
    def vel_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the pebble velocity.
        """
        pass
    
    def __eq__(self, other) -> Any:
        """
        Return self==value.
        """
        pass
    
    def __ge__(self, other) -> Any:
        """
        Return self>=value.
        """
        pass
    
    def __gt__(self, other) -> Any:
        """
        Return self>value.
        """
        pass
    
    def __le__(self, other) -> Any:
        """
        Return self<=value.
        """
        pass
    
    def __lt__(self, other) -> Any:
        """
        Return self<value.
        """
        pass
    
    def __ne__(self, other) -> Any:
        """
        Return self!=value.
        """
        pass
    

class PebbleIter:
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def __iter__(self) -> Any:
        """
        Implement iter(self).
        """
        pass
    
    def __next__(self) -> Any:
        """
        Implement next(self).
        """
        pass
    



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='itasca-stub',
    packages=setuptools.find_packages(),
    version='1.0.10',
    license='MIT',
    description='Itasca PFC python stub',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='panhaoyu',
    author_email='panhaoyu.china@outlook.com',
    url='https://github.com/panhaoyu/itasca-stub',
    download_url='https://github.com/panhaoyu/itasca-stub/archive/1.0.0.tar.gz',
    keywords=['ITASCA', 'STUB', 'PFC'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
    ],
)



from typing import Any

def _plist(*args, **kwargs) -> Any:
    """
    () -> tuple of PyObject pointers for the currenly in-scope and valid intersection set objects.
    This function is used for internal testing and is not needed for general PFC use.
    """
    pass

def count(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the number of intersection sets.
    """
    pass

def find(*args, **kwargs) -> Any:
    """
    (id: int) -> Intersection set object.
    Get the intersection set object with the given ID number.
    """
    pass

def list(*args, **kwargs) -> Any:
    """
    () -> Intersection set iterator object.
    Get an intersection set iterator object.
    """
    pass

def maxid(*args, **kwargs) -> Any:
    """
    () -> int.
    Get the maximum intersection set ID.
    """
    pass

class Setinter:
    __hash__: Any = ...
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def delete(self, *args, **kwargs) -> Any:
        """
        () -> None.
        Delete this intersection set, includingall intersections.
        """
        pass
    
    def id(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the intersection set id.
        """
        pass
    
    def inter_count(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the number of intersections in this intersection set.
        """
        pass
    
    def inters(self, *args, **kwargs) -> Any:
        """
        () -> Intersection iterator object.
        Get an intersection iterator object of all intersections falling within this intersection set.
        """
        pass
    
    def name(self, *args, **kwargs) -> Any:
        """
        () -> string.
        Get the intersection set name.
        """
        pass
    
    def path(self, *args, **kwargs) -> Any:
        """
        (fracture1, fracture2) -> tuple of Fracture objects.
        Get the path between fractures fracture1 and fracture2.
        """
        pass
    
    def __eq__(self, other) -> Any:
        """
        Return self==value.
        """
        pass
    
    def __ge__(self, other) -> Any:
        """
        Return self>=value.
        """
        pass
    
    def __gt__(self, other) -> Any:
        """
        Return self>value.
        """
        pass
    
    def __le__(self, other) -> Any:
        """
        Return self<=value.
        """
        pass
    
    def __lt__(self, other) -> Any:
        """
        Return self<value.
        """
        pass
    
    def __ne__(self, other) -> Any:
        """
        Return self!=value.
        """
        pass
    

class SetinterIter:
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass
    
    def __iter__(self) -> Any:
        """
        Implement iter(self).
        """
        pass
    
    def __next__(self) -> Any:
        """
        Implement next(self).
        """
        pass
    



from typing import Any, Dict
from numpy import ndarray


def create(radii: ndarray, centroids: ndarray,
           props: Dict[str, Any] = None,
           extra: Dict[str, Any] = None,
           ) -> ndarray:
    """
    Create balls from two arrays.
    Keyword arguments can be specified which will set the newly created ball attributes.
    The keyword arguments values can be scalars, vecs or arrays of 1 or two dimensions.
    The props or extra dictionary values can be a 1 or 2 dimensional array of doubles, a number, a vec or a string.
    :param radii: array float{ball}
    :param centroids: array float{ball,dim}
    :param props: used to set ball properties, the value should be a dict of type {str: value}
    :param extra: used to set extra variables, the value should be a dict of type {int: value}
    :return: array int{ball} IDs of the newly created balls
    """
    pass


def damp(*args, **kwargs) -> Any:
    """
    () -> array float{ball}.
    Get a numpy array of the ball local damping.
    """
    pass


def density(*args, **kwargs) -> Any:
    """
    () -> array float{ball}.
    Get a numpy array of the ball density.
    """
    pass


def disp(*args, **kwargs) -> Any:
    """
    () -> array float{ball,2}.
    Get a numpy array of the ball displacement.
    """
    pass


def extra(*args, **kwargs) -> Any:
    """
    (slot: int) -> array float{ball} or float{ball}.
    Get the ball extra data in the given slot as an array.
    Extra variables accessed by array must be of type float or vec.
    """
    pass


def fill_damp(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Fill an existing array with the ball local damping.
    The array must be the correct shape.
    """
    pass


def fill_density(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Fill an existing array with the ball density.
    The array must be the correct shape.
    """
    pass


def fill_disp(*args, **kwargs) -> Any:
    """
    (data: array float{ball,2}) -> None.
    Fill an existing array with the ball displacement.
    The array must be the correct shape.
    """
    pass


def fill_force_app(*args, **kwargs) -> Any:
    """
    (data: array float{ball,2}) -> None.
    Fill an existing array with the ball applied force.
    The array must be the correct shape.
    """
    pass


def fill_force_contact(*args, **kwargs) -> Any:
    """
    (data: array float{ball,2}) -> None.
    Fill an existing array with the ball contact force.
    The array must be the correct shape.
    """
    pass


def fill_force_unbal(*args, **kwargs) -> Any:
    """
    (data: array float{ball,2}) -> None.
    Fill an existing array with the ball unbalanced force.
    The array must be the correct shape.
    """
    pass


def fill_mass(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Fill an existing array with the inertial ball mass.
    The array must be the correct shape.
    """
    pass


def fill_mass_real(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Fill an existing array with the real (gravitational) ball mass.
    The array must be the correct shape.
    """
    pass


def fill_moment_app(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Fill an existing array with the ball applied moment.
    The array must be the correct shape.
    """
    pass


def fill_moment_contact(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Fill an existing array with the ball contact moment.
    The array must be the correct shape.
    """
    pass


def fill_moment_unbal(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Fill an existing array with the ball unbalanced moment.
    The array must be the correct shape.
    """
    pass


def fill_pos(*args, **kwargs) -> Any:
    """
    (data: array float{ball,2}) -> None.
    Fill an existing array with the ball centroid location.
    The array must be the correct shape.
    """
    pass


def fill_radius(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Fill an existing array with the ball radii.
    The array must be the correct shape.
    """
    pass


def fill_rotation(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Fill an existing array with the ball orientation.
    The array must be the correct shape.
    """
    pass


def fill_spin(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Fill an existing array with the ball angular velocity.
    The array must be the correct shape.
    """
    pass


def fill_vel(*args, **kwargs) -> Any:
    """
    (data: array float{ball,2}) -> None.
    Fill an existing array with the ball velocity.
    The array must be the correct shape.
    """
    pass


def force_app(*args, **kwargs) -> Any:
    """
    () -> array float{ball,2}.
    Get a numpy array of the ball applied force.
    """
    pass


def force_contact(*args, **kwargs) -> Any:
    """
    () -> array float{ball,2}.
    Get a numpy array of the ball contact force.
    """
    pass


def force_unbal(*args, **kwargs) -> Any:
    """
    () -> array float{ball,2}.
    Get a numpy array of the ball unbalanced force.
    """
    pass


def ids(*args, **kwargs) -> Any:
    """
    () -> array int{ball}.
    Get the ball ids as an array.
    """
    pass


def in_group(*args, **kwargs) -> Any:
    """
    (group_name: str, slot=1) -> array bool{ball}.
    Return ball group membership as a Boolean array.
    """
    pass


def mass(*args, **kwargs) -> Any:
    """
    () -> array float{ball}.
    Get a numpy array of the inertial ball mass.
    """
    pass


def mass_real(*args, **kwargs) -> Any:
    """
    () -> array float{ball}.
    Get a numpy array of the real (gravitational) ball mass.
    """
    pass


def moment_app(*args, **kwargs) -> Any:
    """
    () -> array float{ball}.
    Get a numpy array of the ball applied moment.
    """
    pass


def moment_contact(*args, **kwargs) -> Any:
    """
    () -> array float{ball}.
    Get a numpy array of the ball contact moment.
    """
    pass


def moment_unbal(*args, **kwargs) -> Any:
    """
    () -> array float{ball}.
    Get a numpy array of the ball unbalanced moment.
    """
    pass


def pos(*args, **kwargs) -> Any:
    """
    () -> array float{ball,2}.
    Get a numpy array of the ball centroid location.
    """
    pass


def radius(*args, **kwargs) -> Any:
    """
    () -> array float{ball}.
    Get a numpy array of the ball radii.
    """
    pass


def rotation(*args, **kwargs) -> Any:
    """
    () -> array float{ball}.
    Get a numpy array of the ball orientation.
    """
    pass


def set_damp(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Set the ball local damping from an array.
    """
    pass


def set_density(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Set the ball density from an array.
    """
    pass


def set_disp(*args, **kwargs) -> Any:
    """
    (data: array float{ball,2}) -> None.
    Set the ball displacement from an array.
    """
    pass


def set_extra(*args, **kwargs) -> Any:
    """
    (slot: int, data: array float{ball} or float{ball}) -> None.
    Set the ball extra data in the given slot with an array.
    Extra variables set by array must be of type float or vec.
    """
    pass


def set_force_app(*args, **kwargs) -> Any:
    """
    (data: array float{ball,2}) -> None.
    Set the ball applied force from an array.
    """
    pass


def set_force_contact(*args, **kwargs) -> Any:
    """
    (data: array float{ball,2}) -> None.
    Set the ball contact force from an array.
    """
    pass


def set_group(*args, **kwargs) -> Any:
    """
    (membership: array bool{ball}, group_name: str, slot=1) -> None.
    Set ball group from an array.
    Where membership True set the corresponding ball to be a member of group group_name in the given slot.
    """
    pass


def set_moment_app(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Set the ball applied moment from an array.
    """
    pass


def set_moment_contact(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Set the ball contact moment from an array.
    """
    pass


def set_pos(*args, **kwargs) -> Any:
    """
    (data: array float{ball,2}) -> None.
    Set the ball centroid location from an array.
    """
    pass


def set_radius(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Set the ball radii from an array.
    """
    pass


def set_rotation(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Set the ball orientation from an array.
    """
    pass


def set_spin(*args, **kwargs) -> Any:
    """
    (data: array float{ball}) -> None.
    Set the ball angular velocity from an array.
    """
    pass


def set_vel(*args, **kwargs) -> Any:
    """
    (data: array float{ball,2}) -> None.
    Set the ball velocity from an array.
    """
    pass


def spin(*args, **kwargs) -> Any:
    """
    () -> array float{ball}.
    Get a numpy array of the ball angular velocity.
    """
    pass


def vel(*args, **kwargs) -> Any:
    """
    () -> array float{ball,2}.
    Get a numpy array of the ball velocity.
    """
    pass



from typing import Any, List, Union, Tuple, Iterator
from itasca import types

from . import facet
from . import thermal
from . import vertex


def _plist(*args, **kwargs) -> Any:
    """
    () -> tuple of PyObject pointers for the currenly in-scope and valid objects.
    This function is used for internal testing and is not needed for general PFC use.
    """
    pass


def count() -> int:
    """
    Get the number of walls.
    """
    pass


def energy(energy_name: str) -> float:
    """
    Get the wall total energy contribution.
    The string argument is the energy name, "energy-boundary" is the only energy type defined.
    """
    pass


def find(id: Union[int, str]) -> 'Wall':
    """
    Get the Wall object with the given ID number or the name.
    """
    pass


def inbox(*args, **kwargs) -> Tuple['Wall']:
    """
    (lower_bound: vec, upper_bound: vec, boundary=False) -> tuple of Wall objects.
    Get walls with extents intersecting a box.
    If the optional keyword argument boundary is True only return the walls inside the extent.
    """
    pass


def list() -> Iterator['Wall']:
    """
    Get a wall iterator object.
    """
    pass


def maxid() -> int:
    """
    Get the maximum wall ID.
    """
    pass


def near(*args, **kwargs) -> 'Wall':
    """
    (point: vec) -> Wall object.
    Find the closest wall to a point.
    """
    pass


class Wall:
    __hash__: Any = ...

    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass

    def closed(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Get the wall closure status.
        A closed wall is one where all edges are shared.
        """
        pass

    def contact_count(self, *args, **kwargs) -> Any:
        """
        (all=False, type=None) -> int.
        Get number of contacts associated with this Wall.
        If the optional keyword argument type is given, the count is limited to the contact types specified.
        The type keyword argument should be a Python type object (one of: itasca.BallBallContact, itasca.BallPebbleContact, itasca.PebblePebbleContact, itasca.BallFacetContact or itasca.PebbleFacetContact).
        If the (optional) keyword argument all is True the count includes virtual contacts.
        """
        pass

    def contacts(self, *args, **kwargs) -> Tuple[types.Contacts]:
        """
        ([piece: object], all=False, type=None) -> tuple of Contact objects.
        Get a tuple of contacts associated with this Wall.
        An optional argument can be included which is a piece object (a Ball, a Pebble or a wallFacet).
        If the optional keyword argument type is given, the returned list is limited to the contact types specified.
        The type keyword argument should be a Python type object (one of: itasca.BallBallContact, itasca.BallPebbleContact, itasca.PebblePebbleContact, itasca.BallFacetContact or itasca.PebbleFacetContact).
        If the (optional) keyword argument all is True the returned list includes virtual contacts.
        """
        pass

    def convex(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Get the convexity status.
        The wall must also be closed to be convex.
        """
        pass

    def cutoff(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the cutoff angle.
        The cutoff angle is used during contact resolution to determine whether or not contact state information is propagated.
        """
        pass

    def delete(self, *args, **kwargs) -> Any:
        """
        () -> None.
        Delete this wall.
        """
        pass

    def disp(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the wall displacement (vector).
        """
        pass

    def disp_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the wall displacement.
        """
        pass

    def disp_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the wall displacement.
        """
        pass

    def extra(self, *args, **kwargs) -> Any:
        """
        (slot: int) -> any.
        Get the wall extra data in the given slot.
        """
        pass

    def facets(self, *args, **kwargs) -> Any:
        """
        () -> Facet iterator object.
        Get the facets of the wall.
        """
        pass

    def force_contact(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the wall contact force (vector).
        """
        pass

    def force_contact_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the wall contact force.
        """
        pass

    def force_contact_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the wall contact force.
        """
        pass

    def fragment(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the wall fragment ID.
        """
        pass

    def group(self, *args, **kwargs) -> Any:
        """
        ([slot: str]) -> str.
        Get the wall group name in a given slot.
        """
        pass

    def group_remove(self, *args, **kwargs) -> Any:
        """
        (group_name: str) -> bool.
        Remove from the given group from all group slots of the wall.
        One argument of type string, giving the group name, is required.
        The return value is a bool which is True if the group was removed from any slot, otherwise False.
        """
        pass

    def groups(self, *args, **kwargs) -> Any:
        """
        () -> {slot: group_name}.
        Get a dictionary describing which groups this wall is part of.
        The keys of the dictionary are the slot names and the values are the group names.
        """
        pass

    def id(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the wall id.
        """
        pass

    def in_group(self, *args, **kwargs) -> Any:
        """
        (group_name: str[, slot: str]) -> bool.
        Test if the wall is part of a given group.
        If the optional argument slot is given, only that slot is searched.
        Otherwise, all group slots are searched.
        """
        pass

    def inside(self, *args, **kwargs) -> Any:
        """
        (point: vec) -> bool.
        Test whether a point is inside a wall.
        The wall must be closed.
        """
        pass

    def moment_contact(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the wall contact moment.
        """
        pass

    def name(self, *args, **kwargs) -> Any:
        """
        () -> str.
        Get the wall name.
        Once a wall has been created its name cannot be changed.
        """
        pass

    def pos(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the wall location (vector).
        """
        pass

    def pos_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the wall location.
        """
        pass

    def pos_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the wall location.
        """
        pass

    def rotation(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the wall orientation.
        """
        pass

    def rotation_center(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the wall center of rotation (vector).
        """
        pass

    def rotation_center_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the wall center of rotation.
        """
        pass

    def rotation_center_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the wall center of rotation.
        """
        pass

    def servo_active(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Get the wall servo activity status.
        """
        pass

    def servo_force(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the wall servo force.
        """
        pass

    def servo_gain(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the wall servo gain.
        """
        pass

    def servo_gainfactor(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the wall servo gain relaxation factor.
        """
        pass

    def servo_gainupdate(self, *args, **kwargs) -> Any:
        """
        () -> int.
        Get the wall servo gain update interval.
        """
        pass

    def servo_set_active(self, *args, **kwargs) -> Any:
        """
        (b:bool) -> None.
        Set the wall servo activity status.
        """
        pass

    def servo_set_force(self, *args, **kwargs) -> Any:
        """
        (force:vec) -> None.
        Set the wall servo force.
        """
        pass

    def servo_set_gainfactor(self, *args, **kwargs) -> Any:
        """
        (fac:float) -> None.
        Set the wall servo gain relaxation factor.
        """
        pass

    def servo_set_gainupdate(self, *args, **kwargs) -> Any:
        """
        (i:int) -> None.
        Set the wall servo gain update interval.
        """
        pass

    def servo_set_vmax(self, *args, **kwargs) -> Any:
        """
        (vmax:float) -> None.
        Set the wall servo cap velocity.
        """
        pass

    def servo_vmax(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the wall servo cap velocity.
        """
        pass

    def set_cutoff(self, *args, **kwargs) -> Any:
        """
        (angle: float) -> None.
        Set the cutoff angle.
        The cutoff angle is used during contact resolution to determine whether or not contact state information is propagated.
        """
        pass

    def set_disp(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the wall displacement (vector).
        """
        pass

    def set_disp_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the wall displacement.
        """
        pass

    def set_disp_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the wall displacement.
        """
        pass

    def set_extra(self, *args, **kwargs) -> Any:
        """
        (slot: int, value: any) -> None.
        Set the wall extra data in the given slot.
        """
        pass

    def set_force_contact(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the wall contact force (vector).
        """
        pass

    def set_force_contact_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the wall contact force.
        """
        pass

    def set_force_contact_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the wall contact force.
        """
        pass

    def set_fragment(self, *args, **kwargs) -> Any:
        """
        (id: int) -> None.
        Set wall fragment ID.
        """
        pass

    def set_group(self, *args, **kwargs) -> Any:
        """
        (group_name: str[, slot: str]) -> None.
        Set the wall group name in a given slot.
        """
        pass

    def set_moment_contact(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the wall contact moment.
        """
        pass

    def set_pos(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the wall location (vector).
        """
        pass

    def set_pos_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the wall location.
        """
        pass

    def set_pos_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the wall location.
        """
        pass

    def set_prop(self, *args, **kwargs) -> Any:
        """
        (name: str, value: any) -> None.
        Set a property of all facets.
        Properties are name-value pairs that are used to fill contact model properties.
        """
        pass

    def set_rotation(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the wall orientation.
        """
        pass

    def set_rotation_center(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the wall center of rotation (vector).
        """
        pass

    def set_rotation_center_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the wall center of rotation.
        """
        pass

    def set_rotation_center_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the wall center of rotation.
        """
        pass

    def set_spin(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the wall angular velocity.
        """
        pass

    def set_vel(self, *args, **kwargs) -> Any:
        """
        (value: vec) -> None.
        Set the wall velocity (vector).
        """
        pass

    def set_vel_x(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the x-component of the wall velocity.
        """
        pass

    def set_vel_y(self, *args, **kwargs) -> Any:
        """
        (value: float) -> None.
        Set the y-component of the wall velocity.
        """
        pass

    def spin(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the wall angular velocity.
        """
        pass

    def valid(self, *args, **kwargs) -> Any:
        """
        () -> bool.
        Returns True if this wall is live.
        """
        pass

    def vel(self, *args, **kwargs) -> Any:
        """
        () -> vec.
        Get the wall velocity (vector).
        """
        pass

    def vel_x(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the x-component of the wall velocity.
        """
        pass

    def vel_y(self, *args, **kwargs) -> Any:
        """
        () -> float.
        Get the y-component of the wall velocity.
        """
        pass

    def vertices(self, *args, **kwargs) -> Any:
        """
        () -> Vertex iterator object.
        Get the vertices of this wall.
        """
        pass

    def __eq__(self, other) -> Any:
        """
        Return self==value.
        """
        pass

    def __ge__(self, other) -> Any:
        """
        Return self>=value.
        """
        pass

    def __gt__(self, other) -> Any:
        """
        Return self>value.
        """
        pass

    def __le__(self, other) -> Any:
        """
        Return self<=value.
        """
        pass

    def __lt__(self, other) -> Any:
        """
        Return self<value.
        """
        pass

    def __ne__(self, other) -> Any:
        """
        Return self!=value.
        """
        pass


class WallIter:
    @classmethod
    def __init__(self, *args, **kwargs) -> None:
        """
        Create and return a new object.
         See help(type) for accurate signature.
        """
        pass

    def __iter__(self) -> Any:
        """
        Implement iter(self).
        """
        pass

    def __next__(self) -> Any:
        """
        Implement next(self).
        """
        pass
